(* Interface Unit to the EGI player DLLs for Borland Delphi.
 * Include this file in Borland Delphi applications that use
 * EPLAY.DLL or EPLAY32.DLL.
 *
 * Version 4.0
 * (c) Copyright ITB CompuPhase, 1996-2003
 *)

unit EPLAY;

interface

{ Include Windows types }
  uses WinTypes, WinProcs, Messages;


const

{ Flags for FlicOpenEx() }
  FLIC_FLAG_MEMORY        =$0001;
  FLIC_FLAG_RESOURCE      =$0002;
  FLIC_FLAG_UNICODE       =$0004;
  FLIC_FLAG_FILEHANDLE    =$0008;
  FLIC_FLAG_DEBUG         =$0010;
  FLIC_FLAG_PASSWORD      =$0100;
  FLIC_FLAG_SCRIPT        =$0400;

{ Parameters for FlicGetParam() and FlicSetParam() }
  FLIC_PARAM_ISPLAYING    = 0;  { 1=FLIC file is currently playing }
  FLIC_PARAM_WIDTH        = 1;
  FLIC_PARAM_HEIGHT       = 2;
  FLIC_PARAM_NUMFRAMES    = 3;  { total number of frames }
  FLIC_PARAM_CURFRAME     = 4;  { current frame number }
  FLIC_PARAM_CONTINUOUS   = 5;  { segment is continuous (it has a ring frame) }
  FLIC_PARAM_SPEED        = 6;  { playback speed, set to 0 for max. speed }
  FLIC_PARAM_DESIGNSPEED  = 7;  { design speed, read from FLIC file }
  FLIC_PARAM_REALSPEED    = 8;  { real playback speed }
  FLIC_PARAM_MODE         = 9;  { BitBlt mode }
  FLIC_PARAM_LOOP         =10;  { loop frames or only play once }
  FLIC_PARAM_NUMSEGMENTS  =11;
  FLIC_PARAM_CURSEGMENT   =12;
  FLIC_PARAM_XPOS         =13;  { position of the animation in the window }
  FLIC_PARAM_YPOS         =14;
  FLIC_PARAM_LABEL        =15;  { label of the current frame (-1 if none) }
  FLIC_PARAM_CHGPAL       =16;  { use current palette, don't create a new one }
  FLIC_PARAM_VERSION      =17;  { current version of EGI player }
  FLIC_PARAM_SEGLABEL     =18;  { the label of the current segment }
  FLIC_PARAM_DRAWFRAME    =19;  { draw the frames? }
  FLIC_PARAM_FRNOTIFY     =20;  { notify for each frame? }
  FLIC_PARAM_MASK         =21;  { masks present (0=no, 1=bitmap, 2=skip-copy, 3=both) }
  FLIC_PARAM_ID           =22;  { user specified id }
  FLIC_PARAM_MSGNUM       =23;  { value of FLIC_NOTIFY }
  FLIC_PARAM_KEYFREQ      =24;  { key frame interval (0 if there are no key frames) }
  FLIC_PARAM_SKIPDELTAS   =25;  { skip all delta frames up to the next key frame }
  FLIC_PARAM_PALMODE      =26;  { palette mode }
  FLIC_PARAM_IDENTPAL     =27;  { 1:1 mapping DIB colour table to palette? }
  FLIC_PARAM_SENDNOTIFY   =28;  { send notification messages? }
  FLIC_PARAM_COLORDEPTH   =29;  { 8=256 colours, 15, 16 or 24 = RGB }
  FLIC_PARAM_NUMREGRECTS  =30;  { number or rectangles that form the region }
  FLIC_PARAM_LASTFRAME    =31;  { last frame to play }
  FLIC_PARAM_PLAYWAVE     =32;  { play audio chunks? }
  FLIC_PARAM_SYNCHRONIZE  =33;  { speed is more important than quality }
  FLIC_PARAM_NEXTSEGMENT  =34;  { segment that (by design) follows this one }
  FLIC_PARAM_REPEATS      =35;  { number of repeats for the segment }
  FLIC_PARAM_DESIGNWIDTH  =36;  { design size, read from FLIC file }
  FLIC_PARAM_DESIGNHEIGHT =37;
  FLIC_PARAM_PRELOAD      =38;  { preload the next frame? }
  FLIC_PARAM_FRAMEBITS    =39;  { data chunks in last frame }
  FLIC_PARAM_XORG         =40;  { position of the origin in the frame's rectangle }
  FLIC_PARAM_YORG         =41;
  FLIC_PARAM_TOTALFRAMES  =42;  { total number of frames (over all segments) }
  FLIC_PARAM_SCALEOPTION  =43;  { method of scaling (point-sampling, smooth Bresenham) }
  FLIC_PARAM_TRANSPCOLOR  =44;  { transparent colour of the animation file (or -1) }
  FLIC_PARAM_OVERLAY      =45;  { label number of the default overlay }
  FLIC_PARAM_OVERLAYIDX   =46;  { "active" index in overlay series }
  FLIC_PARAM_PATHGOAL     =47;  { segment label to move to }

{ Parameters for FlicGetData() and FlicSetData() }
  FLIC_DATA_BITMAP        = 0;  { pointer to the pixel data }
  FLIC_DATA_PALETTE       = 1;  { pointer to the RGB table }
  FLIC_DATA_MASK          = 2;  { pointer to the bitmap mask data }
  FLIC_DATA_BITMAPINFO    = 3;  { pointer to the BITMAPINFO structure }
  FLIC_DATA_WAVEDATA      = 4;  { pointer to the audio samples }
  FLIC_DATA_WAVEHDR       = 5;  { pointer to the WAVEHDR structure }
  FLIC_DATA_WAVEFORMAT    = 6;  { pointer to the WAVEFORMAT structure }
  FLIC_DATA_USERSTRING    = 7;  { pointer to unknown data }
  FLIC_DATA_USERDATA      = 8;  { pointer to user data }
  FLIC_DATA_AMX           = 9;  { pointer to the Small "abstract machine" }
  FLIC_DATA_DDSURFACE     =10;  { pointer to DirectDraw surface }
  FLIC_DATA_RGNDATA       =11;  { pointer to region data }
  FLIC_DATA_LABEL         =12;  { pointer to the last name of a label }

{ Returned bits for FlicNextFrame() and FLIC_PARAM_FRAMEBITS }
  FLIC_FRAME_PAL      = $0001;  { palette needs updating }
  FLIC_FRAME_IMG      = $0002;  { image needs updating, use FlicPaint() }
  FLIC_FRAME_LAST     = $0004;  { last frame has played }
  FLIC_FRAME_RING     = $0008;  { ring frame has played (reset to 2nd frame) }
  FLIC_FRAME_LABEL    = $0010;  { a label was reached }
  FLIC_FRAME_WAVE     = $0020;  { an audio block is ready }
  FLIC_FRAME_USERSTRING=$0040;  { user data block }
  FLIC_FRAME_INFO     = $0080;  { frame information block (origin) }
  FLIC_FRAME_RGNMASK  = $0100;  { region mask data }
  FLIC_FRAME_DECODED  = $8000;  { the frame was decoded correctly }

{ Values for FLIC_PARAM_SENDNOTIFY }
  FLIC_NOTIFY_LAST       =$001; { notify when playing last frame }
  FLIC_NOTIFY_LABEL      =$002; { notify when reaching a label }
  FLIC_NOTIFY_FRAME      =$004; { notify after decoding a frame }
  FLIC_NOTIFY_WAVE       =$008; { notify after decoding a wave block }
  FLIC_NOTIFY_USERSTRING =$010; { notify for user data }
  FLIC_NOTIFY_SEGMENT    =$020; { notify for starting a new segment }
  FLIC_NOTIFY_OVERLAY    =$080; { notify on overlay event (FN_OVERLAY) }
  FLIC_NOTIFY_PATHGOAL   =$100; { notify on path goal reached (FN_PATHGOAL) }


type

{ Values for FLIC_PARAM_MODE }
TFLIC_PARAM_MODE =
(
  FLIC_MODE_BITBLT,
  FLIC_MODE_DIBTODEV,
  FLIC_MODE_STRETCHDIB,
  FLIC_MODE_WING,               { no longer supported }
  FLIC_MODE_DIBSECTION,
  FLIC_MODES                    { number of display modes }
);

{ Values for FLIC_PARAM_PALMODE }
TFLIC_PARAM_PALMODE =
(
  FLIC_PAL_ADAPT,       { adapt to system palette }
  FLIC_PAL_ANIM,        { use the palette from the FLIC file (default) }
  FLIC_PAL_SPECIFIC,    { use the palette passed in by FlicSetHandle() }
  FLIC_PALMODES         { number of palette modes }
);

{ Values for FLIC_PARAM_SCALEOPTION }
TFLIC_PARAM_SCALEOPTION =
(
  FLIC_SCALE_COARSE,    { point sampling }
  FLIC_SCALE_SMOOTH,    { smooth Bresenham, like bi-linear interpolation }
  FLIC_SCALE_ADAPTIVE,  { directional interpolation (adaptive) }
  FLIC_SCALEMODES       { number of scaling modes }
);

{ Flags for the "Method" parameter of several overlay functions }
TFLIC_PARAM_OVLMETHOD =
(
  FLIC_OVL_BYLAYER,     { search by layer number }
  FLIC_OVL_BYLABEL,     { search by label }
  FLIC_OVLMETHODS       { number of methods }
);

{ Parameters for FlicGetHandle() }
FLIC_GET_HANDLE =
(
  FLIC_HANDLE_PALETTE,  { handle to the palette }
  FLIC_HANDLE_BITMAP,   { handle to device dependent bitmap of the frame }
  FLIC_HANDLE_MASK,     { handle to the bitmap mask }
  FLIC_HANDLE_WINGDC,   { handle to WinG Display Context }
  FLIC_HANDLE_WINGBMP,  { handle to WinG bitmap handle }
  FLIC_HANDLE_MUTEX,    { handle to Win32 "mutex" semaphore for bitmap }
  FLIC_HANDLE_HWND,     { handle to window passed to FlicPlay }
  FLIC_HANDLE_WAVE,     { handle to global wave output device }
  FLIC_HANDLE_RGN       { handle to the clip region for the frame (region mask) }
);

{ Parameters for FlicGetRect() }
FLIC_GET_RECT =
(
  FLIC_RECT_BOUNDING,   { bounding box of frame differences }
  FLIC_RECT_MASK,       { bounding box of the mask }
  FLIC_RECT_FIRST,      { first rectangle of the region of frame differences }
  FLIC_RECT_NEXT        { next rectangle of the region of frame differences }
);

{ Returned values for FlicError() }
FLIC_ERROR =
(
  FLIC_ERR_NONE,
  FLIC_ERR_FOPEN,
  FLIC_ERR_FORMAT,
  FLIC_ERR_FREAD,
  FLIC_ERR_MEMORY,
  FLIC_ERR_PARAM,
  FLIC_ERR_INVALID,
  FLIC_ERR_MUTEX,
  FLIC_ERR_UNSUPPORTED,
  FLIC_ERR_LOCKED,
  FLIC_ERR_WAVEOPEN,
  FLIC_ERR_FLICHANDLE,
  FLIC_ERR_GENERIC,
  FLIC_ERR_NUMBER       { number of error codes }
);


const

  { Message posted to the owner window when a label is reached or a segment ends }
  FLIC_COMMAND = WM_USER+97;
  FLIC_NOTIFY  = WM_USER+98;

  { values for wParam upon receipt of FLIC_NOTIFY }
  FN_LABEL      = 0;    { reached a label (LOWORD(lParam)==label) }
  FN_LASTFRAME  = 1;    { played last frame }
  FN_FRAME      = 2;    { played (another) frame }
  FN_WAVE       = 3;    { digitized sound block is ready }
  FN_USERSTRING = 4;    { block of user data is ready }
  FN_SEGMENT    = 5;    { new segment starts playing }
  FN_WINMSG     = 6;    { forwarded Windows message }
  FN_OVERLAY    = 7;    { overlay changed (add/replace/remove) }
  FN_PATHGOAL   = 8;    { path goal reached }

  FC_AUTOCLOSE  = 0;    { close animation when destroying window? }
  FC_RGNMASK    = 1;    { use region mask? }
  FC_DRAGCLIENT = 2;    { move window by dragging the client area? }
  FC_IGNORECLOSE= 3;    { ignore WM_CLOSE? (default=TRUE) }
  FC_TRANSPARENT= 4;    { set transparent colour (layered window) }

type

  __tFLIC = record
                dummy: Integer
            end;
  LPFLIC = ^__tFLIC;

  FLIC_CALLBACK = function(PFlic: LPFLIC; Code: Integer; Data: LongInt): LongInt;

  {$ifndef WIN32}
      PAnsiChar = PChar;
  {$endif}


function  FlicClose(PFlic: LPFLIC): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicCreateWindow(Caption: PAnsiChar;
                           {$ifdef WIN32} dwStyle: LongWord; {$else} dwStyle: LongInt; {$endif}
                           x, y, width, height: Integer; hwndParent: HWnd;
                           reserved: Integer): HWnd;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicError(PFlic: LPFLIC): Integer;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicFindSegment(PFlic: LPFLIC; SegmentName: PAnsiChar): LongInt;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicGetData(PFlic: LPFLIC; Code: Integer): Pointer;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicGetHandle(PFlic: LPFLIC; hdc: HDC; Code: Integer): THandle;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicGetParam(PFlic: LPFLIC; Code: Integer): Integer;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicGetParamStr(PFlic: LPFLIC; paramstr: PAnsiChar): Integer;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicGetRect(PFlic: LPFLIC; Code: Integer; lpRect: PRECT): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicIsValid(PFlic: LPFLIC): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicNextFrame(PFlic: LPFLIC): Word;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOpen(Filename: PAnsiChar): LPFLIC;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOpenEx(Filename: PAnsiChar; Flags: Word; Password: PAnsiChar): LPFLIC;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlay(PFlic: LPFLIC; Layer, XPos, YPos, Label: Word): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlayBitmap(PFlic: LPFLIC; Layer, XPos, YPos: Word;
                            Transparent: TColorRef; Label: Word;
                            hdc: HDC; hbmp: HBITMAP): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlayDIB(PFlic: LPFLIC; Layer, XPos, YPos: Word;
                         Transparent: TColorRef; Label: Word;
                         BmpInfo: PBitmapInfo; BitmapBits: Pointer;
                         AdjustPalette: Bool): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlayPos(PFlic: LPFLIC; LabelOrLayer, XPos, YPos: Word; Method: Integer): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlayRemove(PFlic: LPFLIC; LabelOrLayer: Word; IncludeAbove: Bool;
                            Method: Integer): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicOverlayText(PFlic: LPFLIC; Layer, XPos, YPos: Word;
                          Transparent: TColorRef; Label: Word;
                          Text, Fontname: PAnsiChar;
                          FontSize, FontWeight: Integer; Italic: Bool;
                          TextColor, BackColor: TColorRef): Bool;
                {$ifdef WIN32} stdcall; {$endif}

procedure FlicPaint(PFlic: LPFLIC; hdc: HDC; PaintFlags: Integer);
                {$ifdef WIN32} stdcall; {$endif}

function  FlicPlay(PFlic: LPFLIC; hwnd: HWnd): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetAMXInstance(hinst: THandle): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetCallback(PFlic: LPFLIC; callback: FLIC_CALLBACK): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetData(PFlic: LPFLIC; Code: Integer; Data: Pointer): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetHandle(PFlic: LPFLIC; Code: Integer; handle: THandle): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetParam(PFlic: LPFLIC; Code: Integer; value: Integer): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicSetParamStr(PFlic: LPFLIC; paramstr: PAnsiChar; value: Integer): Bool;
                {$ifdef WIN32} stdcall; {$endif}

function  FlicStop(PFlic: LPFLIC): Bool;
                {$ifdef WIN32} stdcall; {$endif}


implementation

const
  eplaydll = {$ifdef WIN32} 'eplay32.dll' {$else} 'eplay.dll' {$endif} ;

function  FlicClose;          external eplaydll;
function  FlicCreateWindow;   external eplaydll;
function  FlicError;          external eplaydll;
function  FlicFindSegment;    external eplaydll;
function  FlicGetData;        external eplaydll;
function  FlicGetHandle;      external eplaydll;
function  FlicGetParam;       external eplaydll;
function  FlicGetParamStr;    external eplaydll;
function  FlicGetRect;        external eplaydll;
function  FlicIsValid;        external eplaydll;
function  FlicNextFrame;      external eplaydll;
function  FlicOpen;           external eplaydll;
function  FlicOpenEx;         external eplaydll;
function  FlicOverlayBitmap;  external eplaydll;
function  FlicOverlayDIB;     external eplaydll;
function  FlicOverlayPos;     external eplaydll;
function  FlicOverlayRemove;  external eplaydll;
function  FlicOverlayText;    external eplaydll;
procedure FlicPaint;          external eplaydll;
function  FlicPlay;           external eplaydll;
function  FlicSetAMXInstance; external eplaydll;
function  FlicSetCallback;    external eplaydll;
function  FlicSetData;        external eplaydll;
function  FlicSetHandle;      external eplaydll;
function  FlicSetParam;       external eplaydll;
function  FlicSetParamStr;    external eplaydll;
function  FlicStop;           external eplaydll;

end.
